@@ -32,8 +32,8 @@ void yp_add (const char *mount);
 void yp_remove (const char *mount);
 void yp_touch (const char *mount);
 void yp_recheck_config (ice_config_t *config);
-void yp_initialize();
-void yp_shutdown();
+void yp_initialize(void);
+void yp_shutdown(void);
 
 #else
 
@@ -41,7 +41,7 @@ void yp_shutdown();
 #define yp_remove(x)            do{}while(0)
 #define yp_touch(x)             do{}while(0)
 #define yp_recheck_config(x)    do{}while(0)
-#define yp_initialize()         WARN0("YP server handling has been disabled")
+#define yp_initialize()         ICECAST_LOG_WARN("YP server handling has been disabled")
 #define yp_shutdown()           do{}while(0)
 
 #endif /* USE_YP */
